%define anolis_release 3

%bcond_with argon2

Name:           cryptsetup
Version:        2.4.3
Release:        %{anolis_release}%{?dist}
Summary:        Setup program for dm-crypt Based Encrypted Block Devices

License:        GPLv2+ and LGPLv2+
URL:            https://gitlab.com/cryptsetup/cryptsetup
Source0:        https://www.kernel.org/pub/linux/utils/cryptsetup/v2.4/%{name}-%{version}.tar.xz

BuildRequires:  gcc
BuildRequires:  make
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  gettext-devel
BuildRequires:  openssl-devel
BuildRequires:  popt-devel
BuildRequires:  device-mapper-devel
BuildRequires:  libuuid-devel
BuildRequires:  json-c-devel
%if %{with argon2}
BuildRequires:  libargon2-devel
%endif
BuildRequires:  libpwquality-devel
BuildRequires:  libblkid-devel
BuildRequires:  libssh-devel
Requires:       cryptsetup-libs = %{version}-%{release}
Requires:       libpwquality

%description
Cryptsetup is a utility used to conveniently set up disk encryption
based on the DMCrypt kernel module.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Requires: cryptsetup-libs = %{version}-%{release}
Requires: pkgconfig
Summary: Headers and libraries for using encrypted file systems

%description devel
The cryptsetup-devel package contains libraries and header files
used for writing code that makes use of disk encryption.

%package libs
Summary: Cryptsetup shared library

%description libs
This package contains the cryptsetup shared library, libcryptsetup.

%package ssh-token
Summary: Cryptsetup LUKS2 SSH token
Requires: cryptsetup-libs = %{version}-%{release}

%description ssh-token
Experimental cryptsetup plugin for unlocking LUKS2 devices with token
connected to an SSH server.

%package -n veritysetup
Summary: A utility for setting up dm-verity volumes
Requires: cryptsetup-libs = %{version}-%{release}

%description -n veritysetup
The veritysetup package contains a utility for setting up
disk verification using dm-verity kernel module.

%package -n integritysetup
Summary: A utility for setting up dm-integrity volumes
Requires: cryptsetup-libs = %{version}-%{release}

%description -n integritysetup
The integritysetup package contains a utility for setting up
disk integrity protection using dm-integrity kernel module.

%package reencrypt
Summary: A utility for offline reencryption of LUKS encrypted disks
Requires: cryptsetup-libs = %{version}-%{release}

%description reencrypt
This package contains cryptsetup-reencrypt utility which
can be used for offline reencryption of disk in situ.

%prep
%autosetup -p 1

%build
autoreconf -i
%configure --enable-fips \
%if %{with argon2}
	--enable-libargon2 \
%endif
	--enable-pwquality

%make_build

%install
%make_install
find %{buildroot}%{_libdir} -type f -name '*.la' -delete -print

%find_lang cryptsetup

%generate_compatibility_deps

%files
%license COPYING
%{_mandir}/man8/cryptsetup.8.gz
%{_sbindir}/cryptsetup
%{abidir}/cryptsetup-option.list

%files doc
%doc AUTHORS FAQ docs/*ReleaseNotes

%files -n veritysetup
%license COPYING
%{_mandir}/man8/veritysetup.8.gz
%{_sbindir}/veritysetup
%{abidir}/veritysetup-option.list

%files -n integritysetup
%license COPYING
%{_mandir}/man8/integritysetup.8.gz
%{_sbindir}/integritysetup
%{abidir}/integritysetup-option.list

%files reencrypt
%license COPYING
%{_mandir}/man8/cryptsetup-reencrypt.8.gz
%{_sbindir}/cryptsetup-reencrypt
%{abidir}/cryptsetup-reencrypt-option.list

%files devel
%doc docs/examples/*
%{_includedir}/libcryptsetup.h
%{_libdir}/libcryptsetup.so
%{_libdir}/pkgconfig/libcryptsetup.pc

%files libs -f cryptsetup.lang
%dir %{abidir}
%license COPYING COPYING.LGPL
%{_libdir}/libcryptsetup.so.*
%{abidir}/libcryptsetup.dump
%dir %{_libdir}/%{name}/
%{_tmpfilesdir}/cryptsetup.conf
%ghost %attr(700, -, -) %dir /run/cryptsetup

%files ssh-token
%license COPYING COPYING.LGPL
%{_libdir}/%{name}/libcryptsetup-token-ssh.so
%{_mandir}/man8/cryptsetup-ssh.8.gz
%{_sbindir}/cryptsetup-ssh
%{abidir}/cryptsetup-ssh-option.list
%{abidir}/libcryptsetup-token-ssh.dump

%changelog
* Tue Nov 01 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.4.3-3
- optimise spec file & add doc package

* Tue Mar 22 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.4.3-2
- disable argon2

* Thu Mar 03 2022 Su Lifan <su-lifan@linux.alibaba.com> - 2.4.3-1
- Initial packaging for Anolis 23
